import z from "zod";
export declare function isAction(a: any): a is Action;
/**
 * The data model of a discrete Action that is available within the Gluestik Platform.
 */
export interface Action<In = any, Out = any> {
    /**
     * Unique identifier. This ID uniquely identifies this workflow
     * across the entire system.
     */
    id: string;
    /**
     * An optional description of this workflow.
     */
    description?: string;
    /**
     * The input schema for the workflow.
     */
    input: z.ZodType<In>;
    /**
     * The output schema for the workflow.
     */
    output: z.ZodType<Out>;
    /**
     * A function that builds the {@link Workflow}'s logic using the {@link Flow} DSL.
     */
    handle(input: In): Promise<Out>;
}
/**
 * Define a workflow and expose it to the gluestik platform.
 *
 * ```ts
 * import { z } from "zod";
 *
 * export default action({
 *   id: "some unique id",
 *   // use Zod to define the input schema
 *   input: z.object({
 *     inputProp: z.string()
 *   }),
 *   // use Zod to define the output schema
 *   output: z.object({
 *     outputProp: z.string()
 *   }),
 *   // implement the Action's logic
 *   handle: async (input) => {
 *     // implement
 *   }
 * })
 * ```
 */
export declare function action<In, Out>(props: Action<In, Out>): Action<In, Out>;
//# sourceMappingURL=action.d.ts.map